@@ -2,9 +2,19 @@ use std::cmp::Ordering;
 
 use num_complex::Complex;
 
-use super::Collate;
+use super::{Collate, FloatCollator};
 
-impl Collate for Complex<f32> {
+pub struct ComplexCollator<T> {
+    float: FloatCollator<T>,
+}
+
+impl<T> Default for ComplexCollator<T> where FloatCollator<T>: Default {
+    fn default() -> Self {
+        Self { float: FloatCollator::default() }
+    }
+}
+
+impl Collate for ComplexCollator<f32> {
     type Value = Complex<f32>;
 
     fn compare(&self, left: &Self::Value, right: &Self::Value) -> Ordering {
@@ -12,7 +22,7 @@ impl Collate for Complex<f32> {
     }
 }
 
-impl Collate for Complex<f64> {
+impl Collate for ComplexCollator<f64> {
     type Value = Complex<f64>;
 
     fn compare(&self, left: &Self::Value, right: &Self::Value) -> Ordering {
